# Copyright 2004, @Last Software, Inc.
# The code related to click 3 points was reused here from an original
# example titled rectangle.rb by @Last Software, Inc. 
# To it I added the house code. cheers! Tim 
# Name:           Housetool01
# Description:    Create simple houses for mass modeling applications
# Usage:          click 3 points, create a simple house
# Date:           2004,10,25 
# Type:           Tool
# Revised:        2004,10,26 Roof thickness option added 
#                 2004,10,27 Grouping & commenting added
#-----------------------------------------------------------------------------
require 'sketchup.rb'

class Housetool01

def initialize
    @ip = Sketchup::InputPoint.new
    @ip1 = Sketchup::InputPoint.new
    reset
    
    # sets the default house settings
    $heights = 350.cm if not $heights
    $rthick = 25.cm if not $rthick
    $slopes = 30 if not $slopes
     
    # Dialog box
    prompts = ["House height", "Roof Thickness" ,"Roof Slope"]
    values = [$heights, $rthick, $slopes]
    results = inputbox prompts, values, "House parameters"

    return if not results
    $heights, $rthick, $slopes = results
end

def reset
    @pts = []
    @state = 0
    @ip1.clear
    @drawn = false
    Sketchup::set_status_text "", SB_VCB_LABEL
    Sketchup::set_status_text "", SB_VCB_VALUE
    Sketchup::set_status_text "Click anywhere to start"
    @shift_down_time = Time.now
end

def activate
    self.reset
end

def deactivate(view)
    view.invalidate if @drawn
end

def set_current_point(x, y, view)
    if( !@ip.pick(view, x, y, @ip1) )
        return false
    end
    need_draw = true
    
    # Set the tooltip that will be displayed
    view.tooltip = @ip.tooltip
        
    # Compute points
    case @state
    when 0
        @pts[0] = @ip.position
        @pts[4] = @pts[0]
        need_draw = @ip.display? || @drawn
    when 1
        @pts[1] = @ip.position
        @length = @pts[0].distance @pts[1]
        Sketchup::set_status_text @length.to_s, SB_VCB_VALUE
    when 2
        pt1 = @ip.position
        pt2 = pt1.project_to_line @pts
        vec = pt1 - pt2

        @pt1 = @ip.position
        @pt2 = pt1.project_to_line @pts
        @vec = @pt1 - @pt2


        @width = vec.length
        if( @width > 0 )
            # test for a square
            square_point = pt2.offset(vec, @length)
            if( view.pick_helper.test_point(square_point, x, y) )
                @width = @length
                @pts[2] = @pts[1].offset(vec, @width)
                @pts[3] = @pts[0].offset(vec, @width)
                view.tooltip = "Square"
            else
                @pts[2] = @pts[1].offset(vec)
                @pts[3] = @pts[0].offset(vec)
            end
        else
            @pts[2] = @pts[1]
            @pts[3] = @pts[0]
        end
        Sketchup::set_status_text @width.to_s, SB_VCB_VALUE
    end

    view.invalidate if need_draw
end

def onMouseMove(flags, x, y, view)
    self.set_current_point(x, y, view)
end

def create_rectangle
#--------------------------------------------------------------------------
    model = Sketchup.active_model
    model.start_operation "Create House"
    entities = model.active_entities

#Do Grouping: 
#Place a # before each of the 2 following lines to ungroup the house
    group = entities.add_group
    entities = group.entities
        
    # creates a new point from p1 in the direction of p2-p3 with length d
    # params are Point3d, 2 vertices, a length, returns a Point3d
    def translate(p1, p2, p3, d)
        v = p3 - p2
        v.length = d
        trans = Geom::Transformation.translation(v)
        return p1.transform(trans)
    end   
    
    #------plan of house
    base = entities.add_face(@pts[0], @pts[1], @pts[2], @pts[3])
    base.pushpull -$heights
    
    #------create new points at the eaves "$heights"
    @pt0=Geom::Point3d.new(@pts[0][0], @pts[0][1], @pts[0][2]+$heights)
    @pt1=Geom::Point3d.new(@pts[1][0], @pts[1][1], @pts[1][2]+$heights)
    @pt2=Geom::Point3d.new(@pts[2][0], @pts[2][1], @pts[2][2]+$heights)
    @pt3=Geom::Point3d.new(@pts[3][0], @pts[3][1], @pts[3][2]+$heights)

    #------create new points for roof thickness "$rthick"
    @pt00=Geom::Point3d.new(@pts[0][0], @pts[0][1], @pts[0][2]+$heights+$rthick)
    @pt11=Geom::Point3d.new(@pts[1][0], @pts[1][1], @pts[1][2]+$heights+$rthick)
    @pt22=Geom::Point3d.new(@pts[2][0], @pts[2][1], @pts[2][2]+$heights+$rthick)
    @pt33=Geom::Point3d.new(@pts[3][0], @pts[3][1], @pts[3][2]+$heights+$rthick)
        
    #------create a new mid-point pt0m btw. @pt0 & @pt3
    @pt0m = translate( @pt0, @pt0, @pt3, @width/2)
    #------create a new mid-point pt1m btw. $pt1 & @pt2
    @pt1m = translate( @pt1, @pt1, @pt2, @width/2)
         
    @roofpitch=@width/2* Math::tan($slopes.degrees)
    #------create a new point pt3hm (Ridge)
    @pt0mh=Geom::Point3d.new(@pt0m[0], @pt0m[1], @pt0m[2]+@roofpitch)
    #------create a new point pt2hm (Ridge)
    @pt1mh=Geom::Point3d.new(@pt1m[0], @pt1m[1], @pt1m[2]+@roofpitch)

    #------create a new point pt3hm (Ridge+rthick)
    @pt0mh_rthick=Geom::Point3d.new(@pt0m[0], @pt0m[1], @pt0m[2]+@roofpitch+$rthick)
    #------create a new point pt2hm (Ridge+rthick)
    @pt1mh_rthick=Geom::Point3d.new(@pt1m[0], @pt1m[1], @pt1m[2]+@roofpitch+$rthick)
    
    #------Do the inner roof planes           
    base = entities.add_face(@pt3, @pt0mh, @pt1mh,@pt2)
    base = entities.add_face(@pt0, @pt0mh, @pt1mh,@pt1)
    #------Do gable ends
    base = entities.add_face(@pt0, @pt3, @pt0mh)
    base = entities.add_face(@pt1, @pt2, @pt1mh)
    #------Do the outer roof planes           
    base = entities.add_face(@pt33, @pt0mh_rthick, @pt1mh_rthick,@pt22)
    base = entities.add_face(@pt00, @pt0mh_rthick, @pt1mh_rthick,@pt11)
    #------Do roof end gables
    base = entities.add_face(@pt0, @pt00, @pt0mh_rthick, @pt33, @pt3, @pt0mh)
    base = entities.add_face(@pt1, @pt11, @pt1mh_rthick, @pt22, @pt2, @pt1mh)
    #------Do Barge Board
    base = entities.add_face(@pt0, @pt00, @pt11, @pt1)
    base = entities.add_face(@pt3, @pt33, @pt22, @pt2)
#-----------------------------------------------------------------------------
    #view = Sketchup.active_model.active_view 
    #view.zoom_extents 
#----------------------------------------------------------------------------- 
    model.commit_operation
    self.reset
end

def increment_state
    @state += 1
    case @state
    when 1
        @ip1.copy! @ip
        Sketchup::set_status_text "Click for second point"
        Sketchup::set_status_text "Length", SB_VCB_LABEL
        Sketchup::set_status_text "", SB_VCB_VALUE
    when 2
        @ip1.clear
        Sketchup::set_status_text "Click for third point"
        Sketchup::set_status_text "Width", SB_VCB_LABEL
        Sketchup::set_status_text "", SB_VCB_VALUE
    when 3
        self.create_rectangle
    end
end

def onLButtonDown(flags, x, y, view)
    self.set_current_point(x, y, view)
    self.increment_state
    view.lock_inference
end

def onCancel(flag, view)
    view.invalidate if @drawn
    self.reset
end

# This is called when the user types a value into the VCB
def onUserText(text, view)
    # The user may type in something that we can't parse as a length
    # so we set up some exception handling to trap that
    begin
        value = text.to_l
    rescue
        # Error parsing the text
        UI.beep
        value = nil
        Sketchup::set_status_text "", SB_VCB_VALUE
    end
    return if !value
    
    case @state
    when 1
        # update the width
        vec = @pts[1] - @pts[0]
        if( vec.length > 0.0 )
            vec.length = value
            @pts[1] = @pts[0].offset(vec)
            view.invalidate
            self.increment_state
        end
    when 2
        # update the height
        vec = @pts[3] - @pts[0]
        if( vec.length > 0.0 )
            vec.length = value
            @pts[2] = @pts[1].offset(vec)
            @pts[3] = @pts[0].offset(vec)
            self.increment_state
        end
    end
end

def getExtents
    bb = Geom::BoundingBox.new
    case @state
    when 0
        # We are getting the first point
        if( @ip.valid? && @ip.display? )
            bb.add @ip.position
        end
    when 1
        bb.add @pts[0]
        bb.add @pts[1]
    when 2
        bb.add @pts
    end
    bb
end

def draw(view)
    @drawn = false
    
    # Show the current input point
    if( @ip.valid? && @ip.display? )
        @ip.draw(view)
        @drawn = true
    end

    # show the rectangle
    if( @state == 1 )
        # just draw a line from the start to the end point
        view.set_color_from_line(@ip1, @ip)
        inference_locked = view.inference_locked?
        view.line_width = 3 if inference_locked
        view.draw(GL_LINE_STRIP, @pts[0], @pts[1])
        view.line_width = 1 if inference_locked
        @drawn = true
    elsif( @state > 1 )
        # draw the curve
        view.drawing_color = "black"
        view.draw(GL_LINE_STRIP, @pts)
        @drawn = true
    end
end

def onKeyDown(key, rpt, flags, view)
    if( key == CONSTRAIN_MODIFIER_KEY && rpt == 1 )
        @shift_down_time = Time.now
        
        # if we already have an inference lock, then unlock it
        if( view.inference_locked? )
            view.lock_inference
        elsif( @state == 0 )
            view.lock_inference @ip
        elsif( @state == 1 )
            view.lock_inference @ip, @ip1
        end
    end
end

def onKeyUp(key, rpt, flags, view)
    if( key == CONSTRAIN_MODIFIER_KEY &&
        view.inference_locked? &&
        (Time.now - @shift_down_time) > 0.5 )
        view.lock_inference
    end
end
    
end # class Housetool01

#=============================================================================
def Housetool01
    Sketchup.active_model.select_tool Housetool01.new
end

if( not file_loaded?("Housetool01.rb") )
   
end
#-----------------------------------------------------------------------------
file_loaded("Housetool01.rb")

# Copyright 2005, Rick Wilson, based on
# LineTool script, Copyright 2004, @Last Software

# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

# Name :		ParkingTool
# Description :	draws parking spaces
# Author :		RickW
# Usage :		select "Plugins>Draw Parking Spaces" and select first point
#			then type a distance or select a second point
# Date :		2005-06-28
# Type :		tool
# History:
#			1.0 (2005-06-28)	first version 
#-----------------------------------------------------------------------------

require 'sketchup.rb'
require 'linetool.rb'

class Fixnum
	def to_r
		return self*Math::PI/180
	end
end

class ParkingTool < LineTool
	attr_reader :min, :depth, :angle
	attr_writer :min, :depth, :angle

def initialize
	@min=$parking_min_width
	@depth=$parking_depth
	@angle=$parking_angle
	super()
end

# Create new geometry when the user has selected two points.
def create_geometry(pt1, pt2, view)
	ents=view.model.active_entities
	dist=pt1.distance(pt2)
	vec1=width=pt2-pt1
	vec2=Geom::Vector3d.new(vec1.y,-vec1.x,0.0)
	vec2.length=@depth if vec2.length>0
	min=@min
	if @angle!=90
		trans=Geom::Transformation.rotation(pt1, Geom::Vector3d.new(0,0,1), (@angle-90).to_r)
		vec2.transform!(trans)
		vec2.length=@depth + (((sin (@angle-90).abs.to_r)*@min)/(sin @angle.to_r))
		min=@min/(sin @angle.to_r)
	end
	spaces=(dist/min).to_i
	width.length=dist/spaces.to_f if width.length>0
	pt3=pt1.transform(vec2)
	view.model.start_operation "parking lines"
	ents.add_edges(pt3,pt1,pt2)
	#ents.add_line(pt1,pt3)
	1.upto(spaces) do |i|
		pt1.transform!(width)
		pt3.transform!(width)
		ents.add_line(pt1,pt3)
	end
	view.model.commit_operation
end

# Draw the geometry
def draw_geometry(pt1, pt2, view)
	ents=view.model.active_entities
	dist=pt1.distance(pt2)
	vec1=width=pt2-pt1
	vec2=Geom::Vector3d.new(vec1.y,-vec1.x,0.0)
	vec2.length=@depth if vec2.length>0
	min=@min

	if @angle!=90
		trans=Geom::Transformation.rotation(pt1, Geom::Vector3d.new(0,0,1), (@angle-90).to_r)
		vec2.transform!(trans)
		vec2.length=@depth + (((sin (@angle-90).abs.to_r)*@min)/(sin @angle.to_r))
		min=@min/(sin @angle.to_r)
	end

	spaces=(dist/min).to_i
	width.length=dist/spaces.to_f if width.length>0
	pt3=pt1.transform(vec2)
	view.draw_line(pt1,pt2)
	view.draw_line(pt1,pt3)
	1.upto(spaces) do |i|
		pt1.transform!(width)
		pt3.transform!(width)
		view.draw_line(pt1,pt3)
	end
end

end # class ParkingTool

#-----------------------------------------------------------------------------
# These functions are just shortcuts for selecting the new tool & for settings

def draw_parking
#	$parking_depth=18.feet if !$parking_depth
#	$parking_min_width=9.feet if !$parking_min_width
#	prompts=["Minimum Width","Depth"]
#	values=$parking_min_width,$parking_depth
#	results = inputbox prompts, values, "Parking Settings"
#	if results != false
#		$parking_min_width,$parking_depth=results
#		Sketchup.active_model.select_tool ParkingTool.new
#	else
#		return nil
#	end
	draw_parking_settings(nil) if !$parking_depth
	draw_parking_settings(nil) if !$parking_min_width
	draw_parking_settings(nil) if (!$parking_angle || $parking_angle<30 || $parking_angle>150)
	Sketchup.active_model.select_tool ParkingTool.new
end

def draw_parking_settings(mnu)
	$parking_depth=6.m if !$parking_depth
	$parking_min_width=3.m if !$parking_min_width
	$parking_angle=90 if (!$parking_angle || $parking_angle<30 || $parking_angle>150)
	prompts=["Minimum Width","Depth","Angle (degrees)"]
	values=$parking_min_width,$parking_depth,$parking_angle
	results = inputbox prompts, values, "Parking Settings"
	if results != false
		$parking_min_width,$parking_depth,$parking_angle=results
		Sketchup.active_model.select_tool ParkingTool.new
	else
		return nil
	end
	draw_parking if mnu
end

if( not file_loaded?("parking.rb") )
	
end

file_loaded("parking.rb")

#  -----------------------Copyright 2004, Jim Patrick--------------------------
# Modified by D. Bur
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted, provided that the above
# copyright notice appear in all copies, and modified copies that work 
# are posted to the SketchUp Forum.
#  -----------------------------------------------------------------------------
# Creates a user-defined 3D grid of construction lines at the picked point
# -----------------------------------------------------------------------------
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY WARRANTIES
# *************NO WARRANTY MEANS NO WARRANTY******************
# -----------------------------------------------------------------------------

require 'sketchup.rb'

# -----------------------------------------------------------------------------

 def create_3d_colored_grid
    
    # Prompts and default values.
    prompts = ["Length (along X)", "Width (along Y)", "Interval"]
    
    values = [100.cm, 100.cm, 20.cm]

    results = inputbox prompts, values, "Grid parameters"
    width, length, interval, nbr, height = results

# -----------------------------------------------------------------------------

    # Start entity creation.
    model = Sketchup.active_model
    model.start_operation "Create cubic colored Grille"

    entities = model.active_entities
# -----------------------------------------------------------------------------
    group = entities.add_group
    entities = group.entities
    
    # initialize step (stepped interval) , which will increment by the Interval
    step = []
    step[0] = 0
    step[1] = 0
    
    # Initialize the endpoints of the lines
    pts = []                    
    pts[0] = [0, step[0], 0]
    pts[1] = [width, 0, 0]
    pts[2] = [0, step[0], 0]
    pts[3] = [0, length, 0]
    
    # Start drawing the lines.
    # Note - these lines are made dotted 'cause I like 'em that way
    # To get different linetypes, replace all "." with other stipples.
    # Stipple choice is dashed "-", long dash "_", dashdot "-.-"
    # The quotation marks MUST be included
    
    while length >= (step[0] + interval)
    	line1 = entities.add_line(pts[0], pts[1])
    	step[0] = step[0] + interval
    	pts[0] = [0, step[0], 0]
    	pts[1] = [width, step[0], 0]
     end
        # Add one more construction line to finish the rectangle
        line1 = entities.add_line(pts[0], pts[1])

    while 
        width >= (step[1] + interval)
    	line2 = entities.add_line(pts[2], pts[3])
    	step[1] = step[1] + interval
    	pts[2] = [step[1], 0, 0]
    	pts[3] = [step[1], length, 0]
     end
        # Add one more construction line to finish the rectangle
    	line2 = entities.add_line(pts[2], pts[3])



# Close/commit group
    model.commit_operation
    
    group.material = Sketchup::Color.new(255, 0, 0) 
#----------------------------------------------------------------------------- Duplicates 2D grid

  model.start_operation "Duplicate 3D grid"
  pis2 = 1.5707963267948965
    transfo = Geom::Transformation.rotation( [0,0,0], Geom::Vector3d.new(1, 0, 0), pis2)
    new_group = group.copy
    new_group.material = Sketchup::Color.new(0, 255, 0) 
    new_group.move!(transfo)
    transfo = Geom::Transformation.rotation( [0,0,0], Geom::Vector3d.new(0, -1, 0), pis2)
    new_group = group.copy
    new_group.material = Sketchup::Color.new(0, 0, 255) 
    new_group.move!(transfo)

#----------------------------------------------------------------------------- That's all folks
model.commit_operation
end

# -----------------------------------------------------------------------------

# Add item "Grid" to the Draw menu.
# First check for existing menu load
if( not file_loaded?("cubic_colored_grid.rb") )

    
end

# -----------------------------------------------------------------------------
file_loaded("cubic_colored_grid.rb")

#this is the original SU box.rb,Decommented 
#obective use upto to generate an array of boxes 
require 'sketchup.rb'

def create_rand_boxes
    
    prompts = ["Width", "Height", "Depth"]
    values = [100.cm, 100.cm, 100.cm]
    results = inputbox prompts, values, "Box Dimensions"
    width, height, depth = results
#-----------------------------------------------    
    model = Sketchup.active_model
    model.start_operation "Create Boxes"
    entities = model.active_entities
    group = entities.add_group
    entities = group.entities
    
#---------------------------------------------------- 
    prompts = [ "No. of Blocks Horiz.", "No. of Blocks Vert.", "Distance btw. Blocks"]
    values = [5, 5, 200.cm]
    results = inputbox prompts, values, "Boxes Array Size"
    h, v, dist = results

    0.upto(h-1) do |i|                   # Number of boxes across 
      x = (width*i)+(i*dist) 
      0.upto(v-1) do |j|                 # Number of boxes up 
        y = (depth*j)+(j*dist) 
        base = entities.add_face([x, y, 0], [x+width, y, 0], [x+width, y+depth, 0], [x, y+depth, 0])
        base.pushpull -(height*rand(10))
       end
    end

  
    model.commit_operation
end

if( not file_loaded?("boxes_random.rb") )
   
end

#this is the original SU box.rb,Decommented 
#obective use upto to generate an array of boxes 
require 'sketchup.rb'

def create_boxes
    
    prompts = ["Width", "Height", "Depth"]
    values = [100.cm, 100.cm, 100.cm]
    results = inputbox prompts, values, "Box Dimensions"
    width, height, depth = results
#-----------------------------------------------    
    model = Sketchup.active_model
    model.start_operation "Create Boxes"
    entities = model.active_entities
    group = entities.add_group
    entities = group.entities
    base = entities.add_face([0, 0, 0], [width, 0, 0], [width, depth, 0], [0, depth, 0])
    base.pushpull -height
    
#---------------------------------------------------- 
    prompts = [ "No. of Blocks Horiz.", "No. of Blocks Vert.", "Distance btw. Blocks"]
    values = [5, 5, 200.cm]
    results = inputbox prompts, values, "Boxes Array Size"
    h, v, dist = results

    0.upto(h-1) do |i|                   # Number of boxes across 
      x = (width*i)+(i*dist) 
      0.upto(v-1) do |j|                 # Number of boxes up 
        y = (depth*j)+(j*dist) 
        base = entities.add_face([x, y, 0], [x+width, y, 0], [x+width, y+depth, 0], [x, y+depth, 0])
        base.pushpull -height
       end
    end

  
    model.commit_operation
end

if( not file_loaded?("boxes_array.rb") )
   
end

#-----------------------------------------------------------------------------
file_loaded("boxes_array.rb")

#-----------------------------------------------------------------------------
file_loaded("boxes_random.rb")


# Name :          Dome 1.0
# Description :   constructs a dome based on a circle (and interior)
# Author :        Frank Wiesner
# Usage :         1. select circle (and face)
#                 2. run script
# Note:           - a selected face defines the "up" direction
#                 - works with polygons and exploded circle lines
#                 - set @smoothFaces = false if you do not want smooth faces
# Date :          5.Sep.2oo4
# Type :          script
# History:        
#                 1.o (3.Aug.2oo4) - first version

require 'sketchup.rb'

class Dome

def initialize
    @smoothFaces = true
end

def dome_construct
	mo=Sketchup.active_model()
	ss = mo.selection()

	if ss.empty? 
		UI.messagebox("Nothing selected")
	else
		mo.start_operation "dome"
		circleInterior = nil
		edgeArray = Array.new()
		
		ss.each {|e| 
			if (e.kind_of? Sketchup::Edge)
				edgeArray.push(e) 
			end
			circleInterior = e if e.kind_of? Sketchup::Face
		}

		e1 = edgeArray[0]
		p1 = e1.start.position
		p2 = e1.end.position
		
		# get adjacent edge
		vs = e1.end.edges
		if (vs[0] == e1)
			e2 = vs[1]
		else
			e2 = vs[0]
		end

		# get adjacent edge
		p3 = e2.other_vertex(e1.end).position

		# center and normal
		v = p2-p1
		v.length = v.length/2
		mid1 = p1+v
		v = p3-p2
		v.length = v.length/2
		mid2 = p2+v

		# 3 planes
		plane1 = [mid1, e1.line[1]] 
		plane2 = [mid2, e2.line[1]]
		cNormal =  Geom.intersect_plane_plane(plane1,plane2) # gives the normal of the circle through the center
		plane3 = [p1, e1.line[1].cross(e2.line[1])]
		c = Geom.intersect_line_plane(cNormal,plane3)
		
		if (circleInterior != nil)
			normalVec = circleInterior.normal
		else
			normalVec = cNormal[1]
		end

		segments = edgeArray.length/4
		pointsArray = Array.new()
		newEdges = Array.new()
		
		for i in 0..(segments) 
			pt = Geom::Point3d.new(p1.x ,p1.y ,p1.z)
			rot = Geom::Transformation.rotation(c, normalVec.cross(c-p1), i*(90.degrees/segments))
			pt.transform!(rot) 
			pointsArray.push(pt)
		end

		for i in 1..(pointsArray.length-1) 
			newEdges.push(mo.entities.add_edges(pointsArray[i-1], pointsArray[i]).first)
		end

		oldPointsArray = pointsArray
		for k in 1..(edgeArray.length) 
			newPointsArray = Array.new()
			rot = Geom::Transformation.rotation(c, cNormal[1], k*(360.degrees/edgeArray.length))
			for i in 0..(pointsArray.length-1) 
				pt = Geom::Point3d.new(pointsArray[i].x ,pointsArray[i].y ,pointsArray[i].z)
				pt.transform!(rot) 
				newPointsArray.push(pt)
			end
			for i in 0..(newPointsArray.length-2) 
				newEdges.push(mo.entities.add_edges(newPointsArray[i], newPointsArray[i+1]).first)
				newEdges.push(mo.entities.add_edges(oldPointsArray[i], newPointsArray[i]).first)
			end
			for i in 0..(newPointsArray.length-3) 
				mo.entities.add_face(oldPointsArray[i+1], oldPointsArray[i], newPointsArray[i], newPointsArray[i+1])
			end
			mo.entities.add_face(oldPointsArray[oldPointsArray.length-2], newPointsArray[newPointsArray.length-2], newPointsArray[newPointsArray.length-1])
			oldPointsArray = newPointsArray
		end

		if (@smoothFaces) 
			newEdges.each do |e|
				e.smooth=true
				e.soft=true
			end
		end
		mo.commit_operation
	end
end

end #class


domeTool = Dome.new

if( not file_loaded?("dome.rb") )
	
end

file_loaded("dome.rb")



# ---------------------------------------------------------------------------
# Menu items:
#----------------------------------------------------------------------------
    Exterior_menu = UI.menu("Plugins").add_submenu("Exterior Installation")
    Exterior_menu.add_item("HouseTool") { Sketchup.active_model.select_tool Housetool01.new }
    Exterior_menu.add_separator()
    Exterior_menu.add_item("Dome") { domeTool.dome_construct }
    Exterior_menu.add_separator()
    Exterior_menu.add_item("Draw Parking Spaces") { draw_parking }
    Exterior_menu.add_item("Parking Space Settings") { draw_parking_settings(true) }
    Exterior_menu.add_separator()
    Exterior_menu.add_item("Cubic colored grid") { create_3d_colored_grid }
    Exterior_menu.add_separator()
    Exterior_menu.add_item("Boxes") { create_boxes }
    Exterior_menu.add_item("Boxes (random height) array") { create_rand_boxes }
    Exterior_menu.add_separator() 
 